@@ -36,6 +36,9 @@ struct _CountdownHomeWidgetPrivate
 	guint bgOpacity, buttonAreaOpacity;
 	gchar *bgColor, *buttonAreaColor;
 	guint radius;
+	gchar *yearsText, *weeksText, *daysText;
+	gchar *minutesText, *hoursText;
+	gchar *leftText, *agoText;
 	guint offset;
     guint eventID;
 };
@@ -82,13 +85,15 @@ void countdown_home_widget_write_settings (CountdownHomeWidget *self)
 	while (exists) {
 		gchar *title, *date, *time;
 		gboolean showWhich[5];
+		gboolean removePassed;
 		gchar entry[5];
 		snprintf(entry, 5, "%d", i++);
-		gtk_tree_model_get(GTK_TREE_MODEL (self->priv->entries),&iter,0,&title,1,&date,2,&time,4,&showWhich[0],5,&showWhich[1],6,&showWhich[2],7,&showWhich[3],8,&showWhich[4],-1);
+		gtk_tree_model_get(GTK_TREE_MODEL (self->priv->entries),&iter,0,&title,1,&date,2,&time,4,&showWhich[0],5,&showWhich[1],6,&showWhich[2],7,&showWhich[3],8,&showWhich[4],9,&removePassed,-1);
 		g_key_file_set_string(keyFile,entry,"title",title);
 		g_key_file_set_string(keyFile,entry,"date",date);
 		g_key_file_set_string(keyFile,entry,"time",time);
 		g_key_file_set_boolean_list(keyFile,entry,"show",showWhich,5);
+		g_key_file_set_boolean (keyFile, entry, "removePassed", removePassed);
 		exists=gtk_tree_model_iter_next(GTK_TREE_MODEL (self->priv->entries),&iter);
 		g_free(title);
 		g_free(date);
@@ -107,6 +112,13 @@ void countdown_home_widget_write_settings (CountdownHomeWidget *self)
 	g_key_file_set_string (keyFile, "config", "titleFont", self->priv->titleFont);
 	g_key_file_set_string (keyFile, "config", "valueColor", self->priv->valueColor);
 	g_key_file_set_string (keyFile, "config", "valueFont", self->priv->valueFont);
+	g_key_file_set_string (keyFile, "labels", "yearsText", self->priv->yearsText);
+	g_key_file_set_string (keyFile, "labels", "weeksText", self->priv->weeksText);
+	g_key_file_set_string (keyFile, "labels", "daysText", self->priv->daysText);
+	g_key_file_set_string (keyFile, "labels", "hoursText", self->priv->hoursText);
+	g_key_file_set_string (keyFile, "labels", "minutesText", self->priv->minutesText);
+	g_key_file_set_string (keyFile, "labels", "leftText", self->priv->leftText);
+	g_key_file_set_string (keyFile, "labels", "agoText", self->priv->agoText);
 	
 	filename = g_strconcat (HOME_DIR, "/.countdown_home.ini", NULL);
 	fileData = g_key_file_to_data (keyFile, &size, NULL);
@@ -186,6 +198,7 @@ void countdown_home_widget_add_event(GtkWidget *button, GdkEventButton *event, C
 	GtkWidget *dateSelector, *timeSelector;
     GtkWidget *toggleYears, *toggleWeeks, *toggleDays, *toggleHours, *toggleMinutes;
     GtkWidget *displayCaption;
+	GtkWidget *removePassedButton, *removePassedCaption;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
     dialog = gtk_dialog_new_with_buttons ("Add Countdown Event",
@@ -264,6 +277,12 @@ void countdown_home_widget_add_event(GtkWidget *button, GdkEventButton *event, C
 	hildon_caption_set_separator (HILDON_CAPTION (displayCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), displayCaption);
 	g_date_free (date);
+	
+	removePassedButton = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (removePassedButton), "Delete after passed");
+	removePassedCaption = hildon_caption_new (group, "", removePassedButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (removePassedCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), removePassedCaption);
     
     gtk_widget_show_all (dialog);
 
@@ -273,6 +292,7 @@ void countdown_home_widget_add_event(GtkWidget *button, GdkEventButton *event, C
         guint year, month, day;
         guint hours, minutes;
         gboolean tYears, tWeeks, tDays, tHours, tMinutes;
+		gboolean removePassed;
         gchar *printDate, *printTime, *compTime;
 		GtkTreeIter iter;
 
@@ -288,10 +308,11 @@ void countdown_home_widget_add_event(GtkWidget *button, GdkEventButton *event, C
         tDays = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleDays));
         tMinutes = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleMinutes));
         tHours = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleHours));
+		removePassed = hildon_check_button_get_active (HILDON_CHECK_BUTTON (removePassedButton));
 
 		gtk_list_store_append (GTK_LIST_STORE (self->priv->entries), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
-		gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
+		gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, 9, removePassed, -1);
 
         g_free (printDate);
         g_free (printTime);
@@ -314,13 +335,20 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 	GtkWidget *dateSelector, *timeSelector, *positionSelector;
     GtkWidget *toggleYears, *toggleWeeks, *toggleDays, *toggleHours, *toggleMinutes;
     GtkWidget *displayCaption;
+	GtkWidget *removePassedButton, *removePassedCaption;
 	GtkTreeIter iter;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
     dialog = gtk_dialog_new_with_buttons ("Edit Countdown Event",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
         "Save", GTK_RESPONSE_ACCEPT, "Delete", GTK_RESPONSE_NO, NULL);
-    content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	GtkWidget *editArea = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+	GtkWidget *scroll = hildon_pannable_area_new ();
+	g_object_set (scroll, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
+	content_area = gtk_vbox_new (FALSE, 0);
+	hildon_pannable_area_add_with_viewport (HILDON_PANNABLE_AREA (scroll), content_area);
+	gtk_container_add (GTK_CONTAINER (editArea), scroll);
+	gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 350);
     
     titleEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
     hildon_entry_set_placeholder (HILDON_ENTRY (titleEntry), "What do you want to call this?");
@@ -366,6 +394,12 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
     displayCaption = hildon_caption_new (group, "Display", GTK_WIDGET (hbox), NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (displayCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), displayCaption);
+
+	removePassedButton = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	gtk_button_set_label (GTK_BUTTON (removePassedButton), "Delete after passed");
+	removePassedCaption = hildon_caption_new (group, "", removePassedButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (removePassedCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), removePassedCaption);
 	
 	positionPicker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
 	gtk_window_set_title (GTK_WINDOW (positionPicker), "Select position");
@@ -394,12 +428,13 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 		gchar *titleText, *dateText, *timeText;
 		gboolean tYears, tWeeks, tDays;
 		gboolean tHours, tMinutes;
+		gboolean removePassed;
 		gint year, month, day;
 		gint hour, minute;
 		GDate date;
 		gint time;
 		
-		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &titleText, 1, &dateText, 2, &timeText, 4, &tYears, 5, &tWeeks, 6, &tDays, 7, &tHours, 8, &tMinutes, -1);
+		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &titleText, 1, &dateText, 2, &timeText, 4, &tYears, 5, &tWeeks, 6, &tDays, 7, &tHours, 8, &tMinutes, 9, &removePassed, -1);
 		
 		g_date_set_parse (&date, dateText);
 		year = g_date_get_year (&date);
@@ -441,6 +476,7 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleDays), tDays);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleHours), tHours);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleMinutes), tMinutes);
+		hildon_check_button_set_active (HILDON_CHECK_BUTTON (removePassedButton), removePassed);
 	}
 	
     gtk_widget_show_all (dialog);
@@ -451,6 +487,7 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
         guint year, month, day;
         guint hours, minutes;
         gboolean tYears, tWeeks, tDays, tHours, tMinutes;
+		gboolean removePassed;
         gchar *printDate, *printTime, *compTime;
 		GtkTreeIter iter;
 		GtkTreeIter pos;
@@ -469,10 +506,11 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
         tDays = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleDays));
         tMinutes = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleMinutes));
         tHours = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleHours));
+		removePassed = hildon_check_button_get_active (HILDON_CHECK_BUTTON (removePassedButton));
 
 		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
 			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
-			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
+			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, 9, removePassed, -1);
 			
 			if (position < total) {
 				gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &pos, NULL, position);
@@ -564,23 +602,32 @@ void countdown_home_widget_system_settings (HildonCheckButton *button, GtkWidget
 	}
 }
 
+void countdown_home_widget_trans_settings (GtkButton *button, GtkWidget *dialog)
+{
+	gtk_widget_show_all (dialog);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_hide (dialog);
+}
+
 void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHomeWidget *self)
 {
 	//g_warning ("countdown_home_widget_global_options");
     GtkWidget *dialog, *content_area;
     GtkWidget *refreshButton, *fontSettingsButton;
-	GtkWidget *bgSettingsButton;
+	GtkWidget *bgSettingsButton, *transSettingsButton;
     GtkWidget *refreshCaption, *fontSettingsCaption;
-	GtkWidget *bgSettingsCaption;
-	GtkWidget *fontDialog, *bgDialog;
-	GtkWidget *fontContentArea, *bgContentArea;
+	GtkWidget *bgSettingsCaption, *transSettingsCaption;
+	GtkWidget *fontDialog, *bgDialog, *transDialog;
+	GtkWidget *fontContentArea, *bgContentArea, *transContentArea;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	GtkSizeGroup *fontGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	GtkSizeGroup *bgGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+	GtkSizeGroup *transGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	GdkColor color;
 	
 	fontSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 	bgSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	transSettingsButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 
     dialog = gtk_dialog_new_with_buttons ("Countdown Settings",
         NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -730,6 +777,64 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	hildon_caption_set_separator (HILDON_CAPTION (radiusCaption), "");
 	gtk_container_add (GTK_CONTAINER (bgContentArea), radiusCaption);
 	
+	transDialog = gtk_dialog_new_with_buttons ("Change how terms display", dialog,
+		GTK_DIALOG_DESTROY_WITH_PARENT, "Done", GTK_RESPONSE_ACCEPT, NULL);
+	GtkWidget *transMain = gtk_dialog_get_content_area (GTK_DIALOG (transDialog));
+	GtkWidget *scroll = hildon_pannable_area_new ();
+	transContentArea = gtk_vbox_new (TRUE, 0);
+	hildon_pannable_area_add_with_viewport (HILDON_PANNABLE_AREA (scroll), transContentArea);
+	gtk_container_add (GTK_CONTAINER (transMain), scroll);
+	gtk_window_set_default_size (GTK_WINDOW (transDialog), -1, 350);
+	
+	GtkWidget *yearsEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_entry_set_text (HILDON_ENTRY (yearsEntry), self->priv->yearsText);
+	hildon_entry_set_placeholder (HILDON_ENTRY (yearsEntry), self->priv->yearsText);
+	GtkWidget *yearsCaption = hildon_caption_new (transGroup, "Years", yearsEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (yearsCaption), "");
+	gtk_container_add (GTK_CONTAINER (transContentArea), yearsCaption);
+	
+	GtkWidget *weeksEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_entry_set_text (HILDON_ENTRY (weeksEntry), self->priv->weeksText);
+	hildon_entry_set_placeholder (HILDON_ENTRY (weeksEntry), self->priv->weeksText);
+	GtkWidget *weeksCaption = hildon_caption_new (transGroup, "Weeks", weeksEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (weeksCaption), "");
+	gtk_container_add (GTK_CONTAINER (transContentArea), weeksCaption);
+	
+	GtkWidget *daysEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_entry_set_text (HILDON_ENTRY (daysEntry), self->priv->daysText);
+	hildon_entry_set_placeholder (HILDON_ENTRY (daysEntry), self->priv->daysText);
+	GtkWidget *daysCaption = hildon_caption_new (transGroup, "Days", daysEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (daysCaption), "");
+	gtk_container_add (GTK_CONTAINER (transContentArea), daysCaption);
+
+	GtkWidget *hoursEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_entry_set_text (HILDON_ENTRY (hoursEntry), self->priv->hoursText);
+	hildon_entry_set_placeholder (HILDON_ENTRY (hoursEntry), self->priv->hoursText);
+	GtkWidget *hoursCaption = hildon_caption_new (transGroup, "Hours", hoursEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (hoursCaption), "");
+	gtk_container_add (GTK_CONTAINER (transContentArea), hoursCaption);
+	
+	GtkWidget *minutesEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_entry_set_text (HILDON_ENTRY (minutesEntry), self->priv->minutesText);
+	hildon_entry_set_placeholder (HILDON_ENTRY (minutesEntry), self->priv->minutesText);
+	GtkWidget *minutesCaption = hildon_caption_new (transGroup, "Minutes", minutesEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (minutesCaption), "");
+	gtk_container_add (GTK_CONTAINER (transContentArea), minutesCaption);
+	
+	GtkWidget *leftEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_entry_set_text (HILDON_ENTRY (leftEntry), self->priv->leftText);
+	hildon_entry_set_placeholder (HILDON_ENTRY (leftEntry), self->priv->leftText);
+	GtkWidget *leftCaption = hildon_caption_new (transGroup, "Left", leftEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (leftCaption), "");
+	gtk_container_add (GTK_CONTAINER (transContentArea), leftCaption);
+	
+	GtkWidget *agoEntry = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_entry_set_text (HILDON_ENTRY (agoEntry), self->priv->agoText);
+	hildon_entry_set_placeholder (HILDON_ENTRY (agoEntry), self->priv->agoText);
+	GtkWidget *agoCaption = hildon_caption_new (transGroup, "Ago", agoEntry, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (agoCaption), "");
+	gtk_container_add (GTK_CONTAINER (transContentArea), agoCaption);
+	
 	refreshButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
 	g_signal_connect (G_OBJECT (refreshButton), "clicked", G_CALLBACK (countdown_home_widget_select_refresh), picker);
 	
@@ -741,6 +846,10 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	hildon_caption_set_separator (HILDON_CAPTION (refreshCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), refreshCaption);
 	
+	GtkWidget *refreshLabel = gtk_label_new ("'0' will refresh only when switching to the desktop");
+	gtk_label_set_markup (GTK_LABEL (refreshLabel), "<small>'0' will refresh only when switching to the desktop</small>");
+	gtk_container_add (GTK_CONTAINER (content_area), refreshLabel);
+	
 	if (self->priv->systemFont) {
 		gtk_button_set_label (GTK_BUTTON (fontSettingsButton), "System style");
 	} else {
@@ -748,7 +857,7 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 	}
 	g_signal_connect (fontSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_title_settings), fontDialog);
 	
-	fontSettingsCaption = hildon_caption_new (group, "Title", fontSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
+	fontSettingsCaption = hildon_caption_new (group, "Fonts", fontSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (fontSettingsCaption), "");
 	gtk_container_add (GTK_CONTAINER (content_area), fontSettingsCaption);
 
@@ -761,8 +870,15 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 
 	bgSettingsCaption = hildon_caption_new (group, "Background", bgSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (bgSettingsCaption), "");
-	gtk_container_add (GTK_CONTAINER (content_area), bgSettingsCaption);	
-
+	gtk_container_add (GTK_CONTAINER (content_area), bgSettingsCaption);
+	
+	gtk_button_set_label (GTK_BUTTON (transSettingsButton), "Change how terms display");
+	g_signal_connect (transSettingsButton, "clicked", G_CALLBACK (countdown_home_widget_trans_settings), transDialog);
+	
+	transSettingsCaption = hildon_caption_new (group, "Translate", transSettingsButton, NULL, HILDON_CAPTION_MANDATORY);
+	hildon_caption_set_separator (HILDON_CAPTION (transSettingsCaption), "");
+	gtk_container_add (GTK_CONTAINER (content_area), transSettingsCaption);
+	
     gtk_widget_show_all (dialog);
 
     int response=gtk_dialog_run (GTK_DIALOG (dialog));
@@ -788,7 +904,15 @@ void countdown_home_widget_global_options (HDHomePluginItem *hitem, CountdownHom
 		gtk_color_button_get_color (GTK_COLOR_BUTTON (buttonAreaColorButton), &color);
 		self->priv->buttonAreaColor = gdk_color_to_string (&color);
 		self->priv->buttonAreaOpacity = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (buttonAreaOpacitySelector), 0);
-				
+		
+		self->priv->yearsText = g_markup_escape_text(hildon_entry_get_text (HILDON_ENTRY (yearsEntry)),-1);
+		self->priv->weeksText = g_markup_escape_text(hildon_entry_get_text (HILDON_ENTRY (weeksEntry)),-1);
+		self->priv->daysText = g_markup_escape_text(hildon_entry_get_text (HILDON_ENTRY (daysEntry)),-1);
+		self->priv->hoursText = g_markup_escape_text(hildon_entry_get_text (HILDON_ENTRY (hoursEntry)),-1);
+		self->priv->minutesText = g_markup_escape_text(hildon_entry_get_text (HILDON_ENTRY (minutesEntry)),-1);
+		self->priv->leftText = g_markup_escape_text(hildon_entry_get_text (HILDON_ENTRY (leftEntry)),-1);
+		self->priv->agoText = g_markup_escape_text(hildon_entry_get_text (HILDON_ENTRY (agoEntry)),-1);
+		
 		if (self->priv->eventID != 0) {
 			g_source_remove (self->priv->eventID);
 			if (self->priv->refresh > 0) {
@@ -811,7 +935,7 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
     GKeyFile *keyFile;
     GtkTreeIter iter;
 
-	self->priv->entries = gtk_list_store_new (9, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
+	self->priv->entries = gtk_list_store_new (10, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
 
     keyFile = g_key_file_new();
     filename = g_strconcat (HOME_DIR, "/.countdown_home.ini", NULL);
@@ -828,6 +952,7 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
             gchar *title, *date, *time, *readableTime;
             guint seconds, minutes, hours;
             gboolean *showWhich;
+			gboolean removePassed;
             gsize length;
 
             sprintf (entry, "%d", i);
@@ -856,6 +981,12 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 				g_error_free(error);
 				error=NULL;
 			}
+			removePassed=g_key_file_get_boolean (keyFile, entry, "removePassed", &error);
+			if (error) {
+				removePassed = FALSE;
+				g_error_free (error);
+				error = NULL;
+			}
 
 			seconds=g_ascii_strtoll(time,NULL,10);
 			hours=seconds/(60*60);
@@ -863,7 +994,7 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 			readableTime=g_strdup_printf("%02d:%02d",hours,minutes);
 						
 			gtk_list_store_append(self->priv->entries, &iter);
-			gtk_list_store_set(self->priv->entries, &iter,0,title,1,date,2,time,3,readableTime,4,showWhich[0],5,showWhich[1],6,showWhich[2],7,showWhich[3],8,showWhich[4],-1);
+			gtk_list_store_set(self->priv->entries, &iter,0,title,1,date,2,time,3,readableTime,4,showWhich[0],5,showWhich[1],6,showWhich[2],7,showWhich[3],8,showWhich[4],9,removePassed,-1);
 			snprintf(entry,5,"%d",++i);
 			found=g_key_file_has_group(keyFile,entry);
 			g_free(readableTime);
@@ -944,6 +1075,48 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 			g_error_free (error);
 			error = NULL;
 		}
+		self->priv->yearsText = g_key_file_get_string (keyFile, "labels", "yearsText", &error);
+		if (error) {
+			self->priv->yearsText = "years";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->weeksText = g_key_file_get_string (keyFile, "labels", "weeksText", &error);
+		if (error) {
+			self->priv->weeksText = "weeks";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->daysText = g_key_file_get_string (keyFile, "labels", "daysText", &error);
+		if (error) {
+			self->priv->daysText = "days";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->hoursText = g_key_file_get_string (keyFile, "labels", "hoursText", &error);
+		if (error) {
+			self->priv->hoursText = "hours";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->minutesText = g_key_file_get_string (keyFile, "labels", "minutesText", &error);
+		if (error) {
+			self->priv->minutesText = "mins";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->leftText = g_key_file_get_string (keyFile, "labels", "leftText", &error);
+		if (error) {
+			self->priv->leftText = "left";
+			g_error_free (error);
+			error = NULL;
+		}
+		self->priv->agoText = g_key_file_get_string (keyFile, "labels", "agoText", &error);
+		if (error) {
+			self->priv->agoText = "ago";
+			g_error_free (error);
+			error = NULL;
+		}
     } else {
         self->priv->refresh = 1;
 		self->priv->systemBG = TRUE;
@@ -957,6 +1130,13 @@ void countdown_home_widget_make_view ( CountdownHomeWidget *self )
 		self->priv->titleFont = "Sans 18";
 		self->priv->valueColor = "#ababab";
 		self->priv->valueFont = "Sans 16";
+		self->priv->yearsText = "years";
+		self->priv->weeksText = "weeks";
+		self->priv->daysText = "days";
+		self->priv->hoursText = "hours";
+		self->priv->minutesText = "mins";
+		self->priv->leftText = "left";
+		self->priv->agoText = "ago";
     }
 
     g_key_file_free (keyFile);
@@ -1059,15 +1239,16 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 			gint hours=0, minutes=0, seconds=0;
 			gint totDays=0;
 			gboolean showYears, showWeeks, showDays;
-			gboolean showHours, showMinutes;
+			gboolean showHours, showMinutes, removePassed;
 			gchar *tempContent="";
 			gchar **content = g_new0 (gchar*, 6);
 			gchar *contentLabelText="";
 			gint index=0;
 			gchar *tail="";
 			gboolean firstShown;
+			gboolean passed = FALSE;
 			
-			gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &title, 1, &date, 2, &time, 4, &showYears, 5, &showWeeks, 6, &showDays, 7, &showHours, 8, &showMinutes, -1);
+			gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &title, 1, &date, 2, &time, 4, &showYears, 5, &showWeeks, 6, &showDays, 7, &showHours, 8, &showMinutes, 9, &removePassed, -1);
 
 			seconds = g_ascii_strtoll (time, NULL,  10);
 			
@@ -1083,25 +1264,37 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 			seconds = endSec-startSec;
 			
 			if (totDays > 0) {
-				tail = g_strdup_printf ("left");
+				tail = g_strdup_printf (self->priv->leftText);
 				if (seconds < 0) {
 					totDays--;
 					seconds = (60*60*24)+seconds;
 				}
 			} else if (totDays < 0) {
-				tail = g_strdup_printf ("ago");
+				tail = g_strdup_printf (self->priv->agoText);
 				if (seconds > 0) {
 					totDays++;
 					seconds = (60*60*24)-seconds;
+					passed = TRUE;
 				}
 			} else {
 				if (seconds < 0) {
-					tail = g_strdup_printf ("ago");
+					tail = g_strdup_printf (self->priv->agoText);
+					passed = TRUE;
 				} else {
-					tail = g_strdup_printf ("left");
+					tail = g_strdup_printf (self->priv->leftText);
 				}
 			}
 			
+			if (removePassed && passed) {
+				exists = gtk_list_store_remove (self->priv->entries, &iter);
+				g_free (title);
+				g_free (date);
+				g_free (time);
+				g_free (tail);
+				countdown_home_widget_write_settings (self);
+				continue;
+			}
+			
 			firstShown = FALSE;
 
 			totDays=ABS(totDays);
@@ -1112,7 +1305,7 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 				if ((firstShown)||(years!=0)||((!showWeeks)&&(!showDays)&&(!showHours)&&(!showMinutes))) {
 					firstShown = TRUE;
 					tempContent = g_strdup_printf ("%d", ABS (years));
-					content[index++] = g_strconcat (tempContent, " years ", NULL);
+					content[index++] = g_strconcat (tempContent, " ",self->priv->yearsText," ", NULL);
 					g_free (tempContent);
 				}
 			}
@@ -1121,7 +1314,7 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 				if ((firstShown)||(weeks!=0)||((!showDays)&&(!showHours)&&(!showMinutes))) {
 					firstShown = TRUE;
 					tempContent = g_strdup_printf ("%d", ABS (weeks));
-					content[index++] = g_strconcat (tempContent, " weeks ", NULL);
+					content[index++] = g_strconcat (tempContent, " ",self->priv->weeksText," ", NULL);
 					g_free (tempContent);
 				}
 			}
@@ -1130,7 +1323,7 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 				if ((firstShown)||(days!=0)||((!showHours)&&(!showMinutes))) {
 					firstShown = TRUE;
 					tempContent = g_strdup_printf ("%d", ABS (days));
-					content[index++] = g_strconcat (tempContent, " days ", NULL);
+					content[index++] = g_strconcat (tempContent, " ",self->priv->daysText," ", NULL);
 					g_free (tempContent);
 				}
 			}
@@ -1139,7 +1332,7 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 				if ((firstShown)||(hours!=0)||(!showMinutes)) {
 					firstShown = TRUE;
 					tempContent = g_strdup_printf ("%d", ABS (hours));
-					content[index++] = g_strconcat (tempContent, " hours ", NULL);
+					content[index++] = g_strconcat (tempContent, " ",self->priv->hoursText," ", NULL);
 					g_free (tempContent);
 				}
 			}
@@ -1147,7 +1340,7 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 				minutes=((totDays-(days+(weeks*7)+(years*365)))*(24*60))+((seconds/60)-(hours*60));
 				firstShown = TRUE;
 				tempContent = g_strdup_printf ("%d", ABS (minutes));
-				content[index++] = g_strconcat (tempContent, " mins ", NULL);
+				content[index++] = g_strconcat (tempContent, " ",self->priv->minutesText," ", NULL);
 				g_free (tempContent);
 			}
 			content[index] = g_strconcat (tail, NULL);
@@ -1159,7 +1352,11 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 			GtkWidget *vbox = gtk_vbox_new (TRUE, 0);
 			GtkWidget *titleLabel = gtk_label_new (title);
 			gtk_label_set_ellipsize (GTK_LABEL (titleLabel), PANGO_ELLIPSIZE_END);
-			if (!self->priv->systemFont) {
+			if (self->priv->systemFont) {
+				GdkColor color;
+				gtk_style_lookup_color (gtk_rc_get_style (titleLabel), "DefaultTextColor", &color);
+				gtk_label_set_markup (GTK_LABEL (titleLabel), g_strconcat ("<span color=\"", gdk_color_to_string (&color),"\">", title, "</span>", NULL));
+			} else {
 				gtk_label_set_markup (GTK_LABEL (titleLabel), g_strconcat ("<span font=\"", self->priv->titleFont,"\" color=\"",self->priv->titleColor, "\">", title, "</span>", NULL));
 			}
 			GtkWidget *contentLabel = gtk_label_new (contentLabelText);
@@ -1293,7 +1490,9 @@ static gboolean countdown_home_widget_expose_button_area (GtkWidget *widget, Gdk
 
     cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 	if (self->priv->systemBG) {
-		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.75);
+		GdkColor color;
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.8);
 	} else {
 		GdkColor color;
 		gdk_color_parse (self->priv->buttonAreaColor, &color);
@@ -1341,7 +1540,9 @@ static gboolean countdown_home_widget_expose_event (GtkWidget *widget, GdkEventE
 	
 	cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
 	if (self->priv->systemBG) {
-		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.5);
+		GdkColor color;
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
 	} else {
 		GdkColor color;
 		gdk_color_parse (self->priv->bgColor, &color);
